Examples
--------

All classes (except the reports class) correspond to one of the `Product Specific Scopus APIs <https://dev.elsevier.com/api_docs.html>`_.

Search APIs
~~~~~~~~~~~

.. toctree::
    examples/AffiliationSearch.rst
    examples/AuthorSearch.rst
    examples/ScopusSearch.rst

Retrieval APIs
~~~~~~~~~~~~~~

.. toctree::
    examples/AbstractRetrieval.rst
    examples/AuthorRetrieval.rst
    examples/ContentAffiliationRetrieval.rst

Metadata APIs
~~~~~~~~~~~~~

.. toctree::
    examples/CitationOverview.rst
    examples/PlumXMetrics.rst
    examples/SerialSearch.rst
    examples/SerialTitle.rst

One other Metadata API, the Subject Classifications, is not implemented yet.
